The emails, chats, notes, and messages sent by league members.

league_messages(leagueId = ffl_id(), leagueHistory = FALSE, ...)

Arguments

leagueId

Numeric league ID or ESPN fantasy page URL. Defaults to getOption("fflr.leagueId"). Function fails if no ID is found.

leagueHistory

logical; Should the leagueHistory version of the API be called? If TRUE, a list of results is returned, with one element for each historical year of the league.

...

Additional queries passed to httr::GET(). Arguments are converted to a named list and passed to query alongside view.

Value

A tibble of messages.

Examples

league_messages(leagueId = "42654852")
#> # A tibble: 7 × 7
#>   id       type           author date                content messages viewableBy
#>   <chr>    <chr>          <chr>  <dttm>              <chr>   <list>   <list>    
#> 1 3028e0c5 ACTIVITY_STAT… NA     2026-09-08 23:32:17 NA      <df>     <NULL>    
#> 2 11df1b4d ACTIVITY_STAT… NA     2026-09-08 23:11:31 NA      <df>     <NULL>    
#> 3 bcc7a6f1 ACTIVITY_SETT… {22DF… 2026-09-08 23:11:07 NA      <df>     <NULL>    
#> 4 e531eacf ACTIVITY_SETT… {22DF… 2026-09-08 23:09:52 NA      <df>     <NULL>    
#> 5 5ac3c0f6 ACTIVITY_STAT… {22DF… 2026-09-08 23:04:21 NA      <df>     <NULL>    
#> 6 0f22d9c6 CHAT_ALL_MEMB… Weekl… 2023-09-12 15:09:23 NA      <df>     <NULL>    
#> 7 5af42ec9 NOTE           {22DF… 2021-09-13 23:46:07 This [… <list>   <NULL>