Weekly retroactive stat corrections by player.

stat_corrections(date = Sys.Date(), limit = 100)

Arguments

date

A date in the scoring week to return. Defaults to system date. The NFL season is taken from the date, so dates in January and February belong to the season of the previous calendar year.

limit

The limit of corrections to return. Use "" or NULL to return all. Defaults to 100, which is the default limit used by ESPN. Removing the limit can make the request take a long time.

Value

A data frame of stat corrections.