Runs a function fun twice, once with the leagueHistory set to TRUE and
once set to FALSE. Combined the output of both runs into a single data
frame.
combine_history(fun, ...)A data frame of combined outputs.
# requires an `espn_s2` cookie, see `ffl_cookie()`
if (FALSE) { # \dontrun{
combine_history(tidy_scores, leagueId = "252353")
} # }