powered by
The current and projected score for each ongoing match.
live_scoring(leagueId = ffl_id(), yetToPlay = FALSE, ...)
A data frame of scores by period.
Numeric league ID or ESPN fantasy page URL. Defaults to getOption("fflr.leagueId"). Function fails if no ID is found.
getOption("fflr.leagueId")
If TRUE, pro_schedule() and the "mRoster" view are called to determine how many starting players have yet started playing.
TRUE
pro_schedule()
Additional queries passed to httr::GET(). Arguments are converted to a named list and passed to query alongside view.
httr::GET()
query
view
Other scoring functions: tidy_scores()
tidy_scores()
live_scoring(leagueId = "42654852", yetToPlay = FALSE)
Run the code above in your browser using DataLab