The date and method of each player's acquisition onto a fantasy roster.
player_acquire(leagueId = ffl_id(), leagueHistory = FALSE, ...)Numeric league ID or ESPN fantasy page URL. Defaults to
getOption("fflr.leagueId"). Function fails if no ID is found.
logical; Should the leagueHistory version of the API
be called? If TRUE, a list of results is returned, with one element for
each historical year of the league.
Additional queries passed to httr::GET(). Arguments are
converted to a named list and passed to query alongside view.
A data frame of roster players with acquisition method and date.
player_acquire(leagueId = "42654852")
#> $AUS
#> # A tibble: 16 × 12
#> seasonId scoringPeriodId teamId lineupSlot playerId firstName lastName
#> <int> <int> <int> <fct> <int> <chr> <chr>
#> 1 2026 1 1 QB 4426348 Jayden Daniels
#> 2 2026 1 1 RB 4429160 De'Von Achane
#> 3 2026 1 1 RB 4685382 Omarion Hampton
#> 4 2026 1 1 WR 4426515 Puka Nacua
#> 5 2026 1 1 WR 4374302 Amon-Ra St. Brown
#> 6 2026 1 1 TE 4361307 Trey McBride
#> 7 2026 1 1 FLEX 4870808 Jeremiyah Love
#> 8 2026 1 1 D/ST -16026 Seahawks D/ST
#> 9 2026 1 1 K 3953687 Brandon Aubrey
#> 10 2026 1 1 BE 4567048 Kenneth Walker III
#> 11 2026 1 1 BE 4569618 Garrett Wilson
#> 12 2026 1 1 BE 4685472 Tetairoa McMillan
#> 13 2026 1 1 BE 4429615 Zay Flowers
#> 14 2026 1 1 BE 16800 Davante Adams
#> 15 2026 1 1 BE 4696981 Cam Skattebo
#> 16 2026 1 1 BE 3915416 DJ Moore
#> # ℹ 5 more variables: proTeam <fct>, position <fct>, acquisitionType <chr>,
#> # acquisitionDate <dttm>, onTeamId <fct>
#>
#> $BOS
#> # A tibble: 16 × 12
#> seasonId scoringPeriodId teamId lineupSlot playerId firstName lastName
#> <int> <int> <int> <fct> <int> <chr> <chr>
#> 1 2026 1 2 QB 3918298 Josh Allen
#> 2 2026 1 2 RB 4430807 Bijan Robinson
#> 3 2026 1 2 RB 3929630 Saquon Barkley
#> 4 2026 1 2 WR 4430878 Jaxon Smith-Njigba
#> 5 2026 1 2 WR 4241389 CeeDee Lamb
#> 6 2026 1 2 TE 4723086 Colston Loveland
#> 7 2026 1 2 FLEX 3043078 Derrick Henry
#> 8 2026 1 2 D/ST -16007 Broncos D/ST
#> 9 2026 1 2 K 2473037 Jason Myers
#> 10 2026 1 2 BE 4428331 Rashee Rice
#> 11 2026 1 2 BE 4361579 Javonte Williams
#> 12 2026 1 2 BE 4241478 DeVonta Smith
#> 13 2026 1 2 BE 4612826 Ladd McConkey
#> 14 2026 1 2 BE 4882093 Bhayshul Tuten
#> 15 2026 1 2 BE 4596448 Bucky Irving
#> 16 2026 1 2 BE 4431299 Rome Odunze
#> # ℹ 5 more variables: proTeam <fct>, position <fct>, acquisitionType <chr>,
#> # acquisitionDate <dttm>, onTeamId <fct>
#>
#> $CHI
#> # A tibble: 16 × 12
#> seasonId scoringPeriodId teamId lineupSlot playerId firstName lastName
#> <int> <int> <int> <fct> <int> <chr> <chr>
#> 1 2026 1 3 QB 4431452 Drake Maye
#> 2 2026 1 3 RB 4429795 Jahmyr Gibbs
#> 3 2026 1 3 RB 4242335 Jonathan Taylor
#> 4 2026 1 3 WR 4426502 Drake London
#> 5 2026 1 3 WR 4047646 A.J. Brown
#> 6 2026 1 3 TE 4431459 Tyler Warren
#> 7 2026 1 3 FLEX 4379399 James Cook III
#> 8 2026 1 3 D/ST -16034 Texans D/ST
#> 9 2026 1 3 K 4574716 Harrison Mevis
#> 10 2026 1 3 BE 4258173 Nico Collins
#> 11 2026 1 3 BE 4361370 Chris Olave
#> 12 2026 1 3 BE 4430737 Kyren Williams
#> 13 2026 1 3 BE 4595348 Malik Nabers
#> 14 2026 1 3 BE 4567750 Emeka Egbuka
#> 15 2026 1 3 BE 4685702 Quinshon Judkins
#> 16 2026 1 3 BE 4372016 Jaylen Waddle
#> # ℹ 5 more variables: proTeam <fct>, position <fct>, acquisitionType <chr>,
#> # acquisitionDate <dttm>, onTeamId <fct>
#>
#> $DEN
#> # A tibble: 16 × 12
#> seasonId scoringPeriodId teamId lineupSlot playerId firstName lastName
#> <int> <int> <int> <fct> <int> <chr> <chr>
#> 1 2026 1 4 QB 3916387 Lamar Jackson
#> 2 2026 1 4 RB 3117251 Christian McCaffrey
#> 3 2026 1 4 RB 4362238 Chase Brown
#> 4 2026 1 4 WR 4362628 Ja'Marr Chase
#> 5 2026 1 4 WR 4262921 Justin Jefferson
#> 6 2026 1 4 TE 4432665 Brock Bowers
#> 7 2026 1 4 FLEX 4890973 Ashton Jeanty
#> 8 2026 1 4 D/ST -16023 Steelers D/ST
#> 9 2026 1 4 K 4362081 Cameron Dicker
#> 10 2026 1 4 BE 4426354 George Pickens
#> 11 2026 1 4 BE 4427366 Breece Hall
#> 12 2026 1 4 BE 4239996 Travis Etienne Jr.
#> 13 2026 1 4 BE 4239993 Tee Higgins
#> 14 2026 1 4 BE 4259545 D'Andre Swift
#> 15 2026 1 4 BE 3121422 Terry McLaurin
#> 16 2026 1 4 BE 4426388 Jameson Williams
#> # ℹ 5 more variables: proTeam <fct>, position <fct>, acquisitionType <chr>,
#> # acquisitionDate <dttm>, onTeamId <fct>
#>