All available weekly ESPN outlook writeups for NFL players.
player_outlook(leagueId = ffl_id(), limit = 50)Numeric league ID or ESPN fantasy page URL. Defaults to
getOption("fflr.leagueId"). Function fails if no ID is found.
The limit of players to return. Use "" or NULL to return
all. Defaults to 50, which is the default limit used by ESPN. Removing the
limit can make the request take a long time.
A data frame of player outlooks by scoring period.
Other player functions:
all_players(),
list_players(),
player_info(),
player_lookup(),
player_news(),
recent_activity(),
transaction_counter()
player_outlook()
#> # A tibble: 144 × 6
#> seasonId scoringPeriodId id firstName lastName outlook
#> <int> <int> <int> <chr> <chr> <chr>
#> 1 2026 0 4374302 Amon-Ra St. Brown The only player in N…
#> 2 2026 2 4374302 Amon-Ra St. Brown Amon-Ra St. Brown wi…
#> 3 2026 3 4374302 Amon-Ra St. Brown Amon-Ra St. Brown wi…
#> 4 2026 0 3918298 Josh Allen Allen enters his age…
#> 5 2026 2 3918298 Josh Allen Josh Allen appears t…
#> 6 2026 3 3918298 Josh Allen Josh Allen has the B…
#> 7 2026 0 4430878 Jaxon Smith-Njigba The reigning NFL Off…
#> 8 2026 2 4430878 Jaxon Smith-Njigba Jaxon Smith-Njigba w…
#> 9 2026 3 4430878 Jaxon Smith-Njigba Jaxon Smith-Njigba e…
#> 10 2026 0 4429795 Jahmyr Gibbs Gibbs has finished i…
#> # ℹ 134 more rows