All available weekly ESPN outlook writeups for NFL players.
player_outlook(leagueId = ffl_id(), limit = 50)Numeric league ID or ESPN fantasy page URL. Defaults to
getOption("fflr.leagueId"). Function fails if no ID is found.
The limit of players to return. Use "" or NULL to return
all. Defaults to 50, which is the default limit used by ESPN. Removing the
limit can make the request take a long time.
A data frame of player outlooks by scoring period.
Other player functions:
all_players(),
list_players(),
player_info(),
player_news(),
recent_activity(),
transaction_counter()
player_outlook()
#> # A tibble: 50 × 5
#> seasonId id firstName lastName outlook
#> <int> <int> <chr> <chr> <chr>
#> 1 2026 4429795 Jahmyr Gibbs NA
#> 2 2026 4374302 Amon-Ra St. Brown NA
#> 3 2026 4362628 Ja'Marr Chase NA
#> 4 2026 3918298 Josh Allen NA
#> 5 2026 4426515 Puka Nacua NA
#> 6 2026 4430807 Bijan Robinson NA
#> 7 2026 4430878 Jaxon Smith-Njigba NA
#> 8 2026 4241389 CeeDee Lamb NA
#> 9 2026 3117251 Christian McCaffrey NA
#> 10 2026 4379399 James Cook III NA
#> # ℹ 40 more rows